@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
 
 package Tickit;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 
 BEGIN {
-   our $VERSION = '0.54';
+   our $VERSION = '0.55';
 }
 
 use Carp;
@@ -82,7 +82,9 @@ eventually the Window layer will be rewritten in XS and C instead.
 
 =cut
 
-=head2 $tickit = Tickit->new( %args )
+=head2 new
+
+   $tickit = Tickit->new( %args )
 
 Constructs a new C<Tickit> framework container object.
 
@@ -168,6 +170,8 @@ sub new
       my ( $term, $ev, $args ) = @_;
       Tickit::Debug->log( Ik => "Key event %s %s (mod=%d)", @{$args}{qw( type str mod )} ) if DEBUG;
       $weakself->on_key( $args );
+
+      return 1;
    } );
 
    $term->bind_event( mouse => sub {
@@ -175,6 +179,8 @@ sub new
       my ( $term, $ev, $args ) = @_;
       Tickit::Debug->log( Im => "Mouse event %s => %s @%d,%d (mod=%d)", @{$args}{qw( type button col line mod )} ) if DEBUG;
       $weakself->on_mouse( $args );
+
+      return 1;
    } );
 
    $self->set_root_widget( $args{root} ) if defined $args{root};
@@ -196,7 +202,9 @@ sub _make_writer
    return $out;
 }
 
-=head2 $tickit->later( $code )
+=head2 later
+
+   $tickit->later( $code )
 
 Runs the given CODE reference at some time soon in the future. It will not be
 invoked yet, but will be invoked at some point before the next round of input
@@ -220,17 +228,18 @@ sub later
    push @{ $self->{todo_queue} }, $code;
 }
 
-=head2 $tickit->timer( $mode, $amount, $code )
-
-Runs the given CODE reference at some fixed point in time in the future.
-C<$mode> must be either the string C<at>, or C<after>; and specifies that
-C<$amount> gives either the absolute epoch time, or the delay relative to now,
-respectively. Fractions are supported to a resolution of microseconds.
+=head2 timer
 
  $tickit->timer( at => $epoch, $code )
 
  $tickit->timer( after => $delay, $code )
 
+Runs the given CODE reference at some fixed point in time in the future.
+The first argmuent must be either the string C<at>, or C<after>; and specifies
+that second argument gives either the absolute epoch time (C<$epoch>), or the
+delay relative to now (C<$delay>), respectively. Fractions are supported to a
+resolution of microseconds.
+
 =cut
 
 sub timer
@@ -253,7 +262,9 @@ sub timer
    @{ $self->{timer_queue} } = sort { $a->time <=> $b->time } @{ $self->{timer_queue} }, TimeQueue( $at => $code );
 }
 
-=head2 $term = $tickit->term
+=head2 term
+
+   $term = $tickit->term
 
 Returns the underlying L<Tickit::Term> object.
 
@@ -265,9 +276,13 @@ sub term
    return $self->{term};
 }
 
-=head2 $cols = $tickit->cols
+=head2 cols
 
-=head2 $lines = $tickit->lines
+=head2 lines
+
+   $cols = $tickit->cols
+
+   $lines = $tickit->lines
 
 Query the current size of the terminal. Will be cached and updated on receipt
 of C<SIGWINCH> signals.
@@ -298,7 +313,9 @@ sub on_key
    }
 }
 
-=head2 $tickit->bind_key( $key, $code )
+=head2 bind_key
+
+   $tickit->bind_key( $key, $code )
 
 Installs a callback to invoke if the given key is pressed, overwriting any
 previous callback for the same key. The code block is invoked as
@@ -382,7 +399,9 @@ sub on_mouse
    }
 }
 
-=head2 $tickit->rootwin
+=head2 rootwin
+
+   $tickit->rootwin
 
 Returns the root L<Tickit::Window>.
 
@@ -394,7 +413,9 @@ sub rootwin
    return $self->{rootwin};
 }
 
-=head2 $tickit->set_root_widget( $widget )
+=head2 set_root_widget
+
+   $tickit->set_root_widget( $widget )
 
 Sets the root widget for the application's display. This must be a subclass of
 L<Tickit::Widget>.
@@ -407,7 +428,9 @@ sub set_root_widget
    ( $self->{root_widget} ) = @_;
 }
 
-=head2 $tickit->setup_term
+=head2 setup_term
+
+   $tickit->setup_term
 
 Set up the screen and generally prepare to start running
 
@@ -433,7 +456,9 @@ sub setup_term
    $term->flush;
 }
 
-=head2 $tickit->teardown_term
+=head2 teardown_term
+
+   $tickit->teardown_term
 
 Shut down the screen after running
 
@@ -462,7 +487,9 @@ sub teardown_term
    $term->flush;
 }
 
-=head2 $tickit->tick
+=head2 tick
+
+   $tickit->tick
 
 Run a single round of IO events. Does not call C<setup_term> or
 C<teardown_term>.
@@ -507,7 +534,9 @@ sub tick
    $self->_tick;
 }
 
-=head2 $tickit->run
+=head2 run
+
+   $tickit->run
 
 Calls the C<setup_term> method, then processes IO events until stopped, by the
 C<stop> method, C<SIGINT>, C<SIGTERM> or the C<Ctrl-C> key. Then runs the
@@ -555,7 +584,9 @@ sub run
    $self->teardown_term;
 }
 
-=head2 $tickit->stop
+=head2 stop
+
+   $tickit->stop
 
 Causes a currently-running C<run> method to stop processing events and return.
 
