@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::RenderBuffer;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Carp;
 use Scalar::Util qw( refaddr );
@@ -167,7 +167,9 @@ saving state and modifying it, to later restore it again afterwards.
 
 =cut
 
-=head2 $rb = Tickit::RenderBuffer->new( %args )
+=head2 new
+
+   $rb = Tickit::RenderBuffer->new( %args )
 
 Returns a new instance of a C<Tickit::RenderBuffer>.
 
@@ -200,31 +202,43 @@ sub new
 
 =cut
 
-=head2 $lines = $rb->lines
+=head2 lines
 
-=head2 $cols = $rb->cols
+=head2 cols
+
+   $lines = $rb->lines
+
+   $cols = $rb->cols
 
 Returns the size of the buffer area
 
 =cut
 
-=head2 $line = $rb->line
+=head2 line
 
-=head2 $col = $rb->col
+=head2 col
+
+   $line = $rb->line
+
+   $col = $rb->col
 
 Returns the current position of the virtual cursor, or C<undef> if it is not
 set.
 
 =cut
 
-=head2 $rb->save
+=head2 save
+
+   $rb->save
 
 Pushes a new state-saving context to the stack, which can later be returned to
 by the C<restore> method.
 
 =cut
 
-=head2 $rb->savepen
+=head2 savepen
+
+   $rb->savepen
 
 Pushes a new state-saving context to the stack that only stores the pen. This
 can later be returned to by the C<restore> method, but will only restore the
@@ -236,13 +250,17 @@ is better just to pass a different pen directly.
 
 =cut
 
-=head2 $rb->restore
+=head2 restore
+
+   $rb->restore
 
 Pops and restores a saved state previously created with C<save>.
 
 =cut
 
-=head2 $rb->clip( $rect )
+=head2 clip
+
+   $rb->clip( $rect )
 
 Restricts the clipping rectangle of drawing operations to be no further than
 the limits of the given rectangle. This will apply to subsequent rendering
@@ -255,7 +273,9 @@ C<restore> stack.
 
 =cut
 
-=head2 $rb->mask( $rect )
+=head2 mask
+
+   $rb->mask( $rect )
 
 Masks off the given area against any further changes. This will apply to
 subsequent rendering operations but does not affect the existing content, nor
@@ -265,7 +285,9 @@ Areas within the clipping region may be arbitrarily masked. Masks are scoped
 to the depth of the stack they are applied at; once the C<restore> method is
 invoked, any masks applied since its corresponding C<save> will be removed.
 
-=head2 $rb->translate( $downward, $rightward )
+=head2 translate
+
+   $rb->translate( $downward, $rightward )
 
 Applies a translation to the coordinate system used by C<goto> and the
 absolute-position methods C<*_at>. After this call, all positions used will be
@@ -273,7 +295,9 @@ offset by the given amount.
 
 =cut
 
-=head2 $rb->reset
+=head2 reset
+
+   $rb->reset
 
 Removes any pending changes and reverts the C<RenderBuffer> to its default
 empty state. Undefines the virtual cursor position, resets the clipping
@@ -281,20 +305,26 @@ rectangle, and clears the stack of saved state.
 
 =cut
 
-=head2 $rb->clear( $pen )
+=head2 clear
+
+   $rb->clear( $pen )
 
 Resets every cell in the buffer to an erased state. 
 A shortcut to calling C<erase_at> for every line.
 
 =cut
 
-=head2 $rb->goto( $line, $col )
+=head2 goto
+
+   $rb->goto( $line, $col )
 
 Sets the position of the virtual cursor.
 
 =cut
 
-=head2 $rb->setpen( $pen )
+=head2 setpen
+
+   $rb->setpen( $pen )
 
 Sets the rendering pen to use for drawing operations. If a pen is set then a
 C<$pen> argument is optional to any of the drawing methods. If a pen argument
@@ -312,7 +342,9 @@ C<restore> pair may be useful.
 
 =cut
 
-=head2 $rb->skip_at( $line, $col, $len )
+=head2 skip_at
+
+   $rb->skip_at( $line, $col, $len )
 
 Sets the range of cells given to a skipped state. No content will be drawn
 here, nor will any content existing on the terminal be erased.
@@ -321,14 +353,18 @@ Initially, or after calling C<reset>, all cells are set to this state.
 
 =cut
 
-=head2 $rb->skip( $len )
+=head2 skip
+
+   $rb->skip( $len )
 
 Sets the range of cells at the virtual cursor position to a skipped state, and
 updates the position.
 
 =cut
 
-=head2 $rb->skip_to( $col )
+=head2 skip_to
+
+   $rb->skip_to( $col )
 
 Sets the range of cells from the virtual cursor position until before the
 given column to a skipped state, and updates the position to the column.
@@ -338,7 +374,9 @@ and no buffer changes are made.
 
 =cut
 
-=head2 $cols = $rb->text_at( $line, $col, $text, $pen )
+=head2 text_at
+
+   $cols = $rb->text_at( $line, $col, $text, $pen )
 
 Sets the range of cells starting at the given position, to render the given
 text in the given pen.
@@ -348,7 +386,9 @@ than was actually printed).
 
 =cut
 
-=head2 $cols = $rb->text( $text, $pen )
+=head2 text
+
+   $cols = $rb->text( $text, $pen )
 
 Sets the range of cells at the virtual cursor position to render the given
 text in the given pen, and updates the position.
@@ -358,20 +398,26 @@ than was actually printed).
 
 =cut
 
-=head2 $rb->erase_at( $line, $col, $len, $pen )
+=head2 erase_at
+
+   $rb->erase_at( $line, $col, $len, $pen )
 
 Sets the range of cells given to erase with the given pen.
 
 =cut
 
-=head2 $rb->erase( $len, $pen )
+=head2 erase
+
+   $rb->erase( $len, $pen )
 
 Sets the range of cells at the virtual cursor position to erase with the given
 pen, and updates the position.
 
 =cut
 
-=head2 $rb->erase_to( $col, $pen )
+=head2 erase_to
+
+   $rb->erase_to( $col, $pen )
 
 Sets the range of cells from the virtual cursor position until before the
 given column to erase with the given pen, and updates the position to the
@@ -382,7 +428,9 @@ and no buffer changes are made.
 
 =cut
 
-=head2 $rb->eraserect( $rect, $pen )
+=head2 eraserect
+
+   $rb->eraserect( $rect, $pen )
 
 Sets the range of cells given by the rectangle to erase with the given pen.
 
@@ -469,21 +517,27 @@ calls, without end caps:
 
 =cut
 
-=head2 $rb->hline_at( $line, $startcol, $endcol, $style, $pen, $caps )
+=head2 hline_at
+
+   $rb->hline_at( $line, $startcol, $endcol, $style, $pen, $caps )
 
 Draws a horizontal line between the given columns (both are inclusive), in the
 given line style, with the given pen.
 
 =cut
 
-=head2 $rb->vline_at( $startline, $endline, $col, $style, $pen, $caps )
+=head2 vline_at
+
+   $rb->vline_at( $startline, $endline, $col, $style, $pen, $caps )
 
 Draws a vertical line between the centres of the given lines (both are
 inclusive), in the given line style, with the given pen.
 
 =cut
 
-=head2 $rb->linebox_at( $startline, $endline, $startcol, $endcol, $style, $pen )
+=head2 linebox_at
+
+   $rb->linebox_at( $startline, $endline, $startcol, $endcol, $style, $pen )
 
 A convenient shortcut to calling two C<hline_at> and two C<vline_at> in order
 to draw a rectangular box.
@@ -502,14 +556,18 @@ sub linebox_at
    $self->vline_at( $startline, $endline, $endcol,   $style, $pen );
 }
 
-=head2 $rb->char_at( $line, $col, $codepoint, $pen )
+=head2 char_at
+
+   $rb->char_at( $line, $col, $codepoint, $pen )
 
 Sets the given cell to render the given Unicode character (as given by
 codepoint number, not character string) in the given pen.
 
 =cut
 
-=head2 $rb->char( $codepoint, $pen )
+=head2 char
+
+   $rb->char( $codepoint, $pen )
 
 Sets the cell at the virtual cursor position to render the given Unicode
 character (as given by codepoint number, not character string) in the given
@@ -521,7 +579,9 @@ efficient than many single-column wide C<text_at> calls.
 
 =cut
 
-=head2 $cell = $rb->get_cell( $line, $col )
+=head2 get_cell
+
+   $cell = $rb->get_cell( $line, $col )
 
 Returns a structure containing the content stored in the given cell. The
 C<$cell> structure responds to the following methods:
@@ -579,7 +639,9 @@ sub get_cell
    }
 }
 
-=head2 $rb->flush_to_term( $term )
+=head2 flush_to_term
+
+   $rb->flush_to_term( $term )
 
 Renders the stored content to the given L<Tickit::Term>. After this, the
 buffer will be cleared and reset back to initial state.
