@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2012 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2012-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::StringPos;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 # XS code comes from Tickit itself
 require Tickit;
@@ -54,17 +54,27 @@ to -1 to indicate no limit in that counter.
 
 =head1 CONSTRUCTORS
 
-=head2 $pos = Tickit::StringPos->zero
+=head2 zero
+
+   $pos = Tickit::StringPos->zero
 
 Returns a new instance with all counters set to zero.
 
-=head2 $pos = Tickit::StringPos->limit_bytes( $bytes )
+=head2 limit_bytes
 
-=head2 $pos = Tickit::StringPos->limit_codepoints( $codepoints )
+=head2 limit_codepoints
 
-=head2 $pos = Tickit::StringPos->limit_graphemes( $graphemes )
+=head2 limit_graphemes
 
-=head2 $pos = Tickit::StringPos->limit_columns( $columns )
+=head2 limit_columns
+
+   $pos = Tickit::StringPos->limit_bytes( $bytes )
+
+   $pos = Tickit::StringPos->limit_codepoints( $codepoints )
+
+   $pos = Tickit::StringPos->limit_graphemes( $graphemes )
+
+   $pos = Tickit::StringPos->limit_columns( $columns )
 
 Return a new instance with one counter set to the given limit and the other
 three counters set to -1.
@@ -73,13 +83,21 @@ three counters set to -1.
 
 =head1 METHODS
 
-=head2 $bytes = $pos->bytes
+=head2 bytes
 
-=head2 $codepoints = $pos->codepoints
+=head2 codepoints
 
-=head2 $graphemes = $pos->graphemes
+=head2 graphemes
 
-=head2 $columns = $pos->columns
+=head2 columns
+
+   $bytes = $pos->bytes
+
+   $codepoints = $pos->codepoints
+
+   $graphemes = $pos->graphemes
+
+   $columns = $pos->columns
 
 Return the current value the counters.
 
