@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Term;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Carp;
 
@@ -52,7 +52,9 @@ distribution.
 
 =cut
 
-=head2 $term = Tickit::Term->find_for_term( %params )
+=head2 find_for_term
+
+   $term = Tickit::Term->find_for_term( %params )
 
 Attempts to load and construct a subclass determined by the current terminal
 type (as given by C<$ENV{TERM}>). If this fails, returns a normal
@@ -76,7 +78,9 @@ sub find_for_term
    return $class->new( @_ );
 }
 
-=head2 $term = Tickit::Term->new( %params )
+=head2 new
+
+   $term = Tickit::Term->new( %params )
 
 Constructs a new C<Tickit::Term> object.
 
@@ -141,38 +145,50 @@ sub new
 
 =cut
 
-=head2 $fh = $term->get_input_handle
+=head2 get_input_handle
+
+   $fh = $term->get_input_handle
 
 Returns the input handle set by the C<input_handle> constructor arg.
 
 =cut
 
-=head2 $fh = $term->get_output_handle
+=head2 get_output_handle
+
+   $fh = $term->get_output_handle
 
 Returns the output handle set by the C<output_handle> constructor arg.
 
 =cut
 
-=head2 $term->set_output_buffer( $len )
+=head2 set_output_buffer
+
+   $term->set_output_buffer( $len )
 
 Sets the size of the output buffer
 
 =cut
 
-=head2 $term->await_started( $timeout )
+=head2 await_started
+
+   $term->await_started( $timeout )
 
 Waits for the terminal startup process to complete, up to the timeout given in
 seconds.
 
 =cut
 
-=head2 $term->flush
+=head2 flush
+
+   $term->flush
 
 Flushes the output buffer to the terminal
 
 =cut
 
-=head2 $id = $term->bind_event( $ev, $code, $data )
+=head2 bind_event
+
+   $id = $term->bind_event( $ev, $code, $data )
 
 Installs a new event handler to watch for the event specified by C<$ev>,
 invoking the C<$code> reference when it occurs. C<$code> will be invoked with
@@ -180,7 +196,7 @@ the given the terminal, the event name, a C<HASH> reference containing event
 arguments, and the C<$data> value. It returns an ID value that may be used to
 remove the handler by calling C<unbind_event_id>.
 
- $code->( $term, $ev, $args, $data )
+ $ret = $code->( $term, $ev, $args, $data )
 
 The C<$args> hash will contain keys depending on the event type:
 
@@ -207,9 +223,33 @@ The hash will contain C<lines> and C<cols> as integers.
 
 =back
 
+This method is aliased as C<bind_event_default> for forward compatibility to
+account for L</bind_event_with_flags> being renamed to simply C<bind_event>.
+
 =cut
 
-=head2 $term->unbind_event_id( $id )
+# Eventually throw a deprecation warning
+*bind_event = \&bind_event_default;
+
+=head2 bind_event_with_flags
+
+   $id = $term->bind_event_with_flags( $ev, $flags, $code, $data )
+
+Similar to L</bind_event> but passes the C<$flags> argument too. This should
+be zero to apply default semantics, or a bitmask of one or more of the
+following constants:
+
+=over 4
+
+=item TICKIT_BIND_FIRST
+
+Inserts this event handler first in the chain, before any existing ones.
+
+=back
+
+=head2 unbind_event_id
+
+   $term->unbind_event_id( $id )
 
 Removes an event handler that returned the given C<$id> value.
 
@@ -251,7 +291,9 @@ sub set_on_mouse
    } );
 }
 
-=head2 $term->refresh_size
+=head2 refresh_size
+
+   $term->refresh_size
 
 If a filehandle was supplied to the constructor, fetch the size of the
 terminal and update the cached sizes in the object. May invoke C<on_resize> if
@@ -259,16 +301,22 @@ the new size is different.
 
 =cut
 
-=head2 $term->set_size( $lines, $cols )
+=head2 set_size
+
+   $term->set_size( $lines, $cols )
 
 Defines the size of the terminal. Invoke C<on_resize> if the new size is
 different.
 
 =cut
 
-=head2 $lines = $term->lines
+=head2 lines
 
-=head2 $cols = $term->cols
+=head2 cols
+
+   $lines = $term->lines
+
+   $cols = $term->cols
 
 Query the size of the terminal, as set by the most recent C<refresh_size> or
 C<set_size> operation.
@@ -278,7 +326,9 @@ C<set_size> operation.
 sub lines { ( shift->get_size )[0] }
 sub cols  { ( shift->get_size )[1]  }
 
-=head2 $success = $term->goto( $line, $col )
+=head2 goto
+
+   $success = $term->goto( $line, $col )
 
 Move the cursor to the given position on the screen. If only one parameter is
 defined, does not alter the other. Both C<$line> and C<$col> are 0-based.
@@ -289,13 +339,17 @@ move it will need to be retried using a fully-specified call.
 
 =cut
 
-=head2 $term->move( $downward, $rightward )
+=head2 move
+
+   $term->move( $downward, $rightward )
 
 Move the cursor relative to where it currently is.
 
 =cut
 
-=head2 $success = $term->scrollrect( $top, $left, $lines, $cols, $downward, $rightward )
+=head2 scrollrect
+
+   $success = $term->scrollrect( $top, $left, $lines, $cols, $downward, $rightward )
 
 Attempt to scroll the rectangle of the screen defined by the first four
 parameters by an amount given by the latter two. Since most terminals cannot
@@ -308,9 +362,11 @@ undefined if this method returns successful.
 
 =cut
 
-=head2 $term->chpen( $pen )
+=head2 chpen
 
-=head2 $term->chpen( %attrs )
+   $term->chpen( $pen )
+
+   $term->chpen( %attrs )
 
 Changes the current pen attributes to those given. Any attribute whose value
 is given as C<undef> is reset. Any attributes not named are unchanged.
@@ -319,16 +375,20 @@ For details of the supported pen attributes, see L<Tickit::Pen>.
 
 =cut
 
-=head2 $term->setpen( $pen )
+=head2 setpen
 
-=head2 $term->setpen( %attrs )
+   $term->setpen( $pen )
+
+   $term->setpen( %attrs )
 
 Similar to C<chpen>, but completely defines the state of the terminal pen. Any
 attribute not given will be reset to its default value.
 
 =cut
 
-=head2 $term->print( $text, [ $pen ] )
+=head2 print
+
+   $term->print( $text, [ $pen ] )
 
 Print the given text to the terminal at the current cursor position.
 
@@ -337,7 +397,9 @@ given to C<setpen> first.
 
 =cut
 
-=head2 $term->clear( [ $pen ] )
+=head2 clear
+
+   $term->clear( [ $pen ] )
 
 Erase the entire screen.
 
@@ -346,7 +408,9 @@ given to C<setpen> first.
 
 =cut
 
-=head2 $term->erasech( $count, $moveend, [ $pen ] )
+=head2 erasech
+
+   $term->erasech( $count, $moveend, [ $pen ] )
 
 Erase C<$count> characters forwards. If C<$moveend> is true, the cursor is
 moved to the end of the erased region. If defined but false, the cursor will
@@ -363,9 +427,13 @@ given to C<setpen> first.
 
 =cut
 
-=head2 $value = $term->getctl_int( $ctl )
+=head2 getctl_int
 
-=head2 $success = $term->setctl_int( $ctl, $value )
+=head2 setctl_int
+
+   $value = $term->getctl_int( $ctl )
+
+   $success = $term->setctl_int( $ctl, $value )
 
 Gets or sets the value of an integer terminal control option. C<$ctl> should
 be one of the following options. They can be specified either as integers,
@@ -405,7 +473,9 @@ C<TERM_MOUSEMODE_OFF>.
 
 =back
 
-=head2 $success = $term->setctl_str( $ctl, $value )
+=head2 setctl_str
+
+   $success = $term->setctl_str( $ctl, $value )
 
 Sets the value of a string terminal control option. C<$ctrl> should be one of
 the following options. They can be specified either as integers or strings, as
@@ -425,20 +495,26 @@ Sets the terminal window icon text, title, or both.
 
 =cut
 
-=head2 $term->input_push_bytes( $bytes )
+=head2 input_push_bytes
+
+   $term->input_push_bytes( $bytes )
 
 Feeds more bytes of input. May result in C<on_key> or C<on_mouse> events.
 
 =cut
 
-=head2 $term->input_readable
+=head2 input_readable
+
+   $term->input_readable
 
 Informs the term that the input handle may be readable. Attempts to read more
 bytes of input. May result in C<on_key> or C<on_mouse> events.
 
 =cut
 
-=head2 $term->input_wait( $timeout )
+=head2 input_wait
+
+   $term->input_wait( $timeout )
 
 Block until some input is available, and process it. Returns after one round
 of input has been processed. May result in C<on_key> or C<on_mouse> events. If
@@ -447,7 +523,9 @@ before returning, even if no input events were received.
 
 =cut
 
-=head2 $timeout = $term->check_timeout
+=head2 check_timeout
+
+   $timeout = $term->check_timeout
 
 Returns a number in seconds to represent when the next timeout should occur on
 the terminal, or C<undef> if nothing is waiting. May invoke expired timeouts,
@@ -455,6 +533,47 @@ and cause a C<on_key> event to occur.
 
 =cut
 
+=head2 emit_key
+
+   $term->emit_key(
+      type => $type, str => $str, [ mod => $mod ]
+   )
+
+Invokes the key event handlers as if an event with the given info had just
+been received. The C<mod> argument is optional, a default of 0 will apply if
+it is missing.
+
+=cut
+
+sub emit_key
+{
+   my $self = shift;
+   my %args = @_;
+
+   $self->_emit_key( @args{qw( type str )}, $args{mod} // 0 );
+}
+
+=head2 emit_mouse
+
+   $term->emit_mouse(
+      type => $type, button => $button, line => $line, col => $col,
+      [ mod => $mod ]
+   )
+
+Invokes the mouse event handlers as if an event with the given info had just
+been received. The C<mod> argument is optional, a default of 0 will apply if
+it is missing.
+
+=cut
+
+sub emit_mouse
+{
+   my $self = shift;
+   my %args = @_;
+
+   $self->_emit_mouse( @args{qw( type button line col )}, $args{mod} // 0 );
+}
+
 =head1 TODO
 
 =over 4
