@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Test;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Carp;
 
@@ -103,7 +103,9 @@ installable module, so that authors of widget subclasses can use it too.
 my $term;
 my $tickit;
 
-=head2 $term = mk_term
+=head2 mk_term
+
+   $term = mk_term
 
 Constructs and returns the mock terminal to unit test with. This object will
 be cached and returned if this function is called again. Most unit tests will
@@ -121,7 +123,9 @@ sub mk_term
    return $term ||= Tickit::Test::MockTerm->new( @_ );
 }
 
-=head2 $win = mk_window
+=head2 mk_window
+
+   $win = mk_window
 
 Construct a root window using the mock terminal, to unit test with.
 
@@ -145,7 +149,9 @@ sub mk_window
    return $win;
 }
 
-=head2 ( $term, $win ) = mk_term_and_window
+=head2 mk_term_and_window
+
+   ( $term, $win ) = mk_term_and_window
 
 Constructs and returns the mock terminal and root window; equivalent to
 calling each of C<mk_term> and C<mk_window> separately.
@@ -172,6 +178,8 @@ sub cols  { return $term->cols  }
 
 =head2 flush_tickit
 
+   flush_tickit
+
 Flushes any pending C<later> events in the testing C<Tickit> object. Because
 the unit test script has no real event loop, this is required instead, to
 flush any pending events.
@@ -188,6 +196,8 @@ sub flush_tickit
 
 =head2 drain_termlog
 
+   drain_termlog
+
 Drains any pending events from the method log used by the C<is_termlog> test.
 Useful to clear up non-tested events before running a test.
 
@@ -200,6 +210,8 @@ sub drain_termlog
 
 =head2 clear_term
 
+   clear_term
+
 Clears the entire content form the mock terminal. Useful at the end of a
 section of tests before starting another one. Don't forget to C<drain_termlog>
 afterwards.
@@ -211,7 +223,9 @@ sub clear_term
    $term->clear
 }
 
-=head2 resize_term( $lines, $cols )
+=head2 resize_term
+
+   resize_term( $lines, $cols )
 
 Resize the virtual testing terminal to the size given
 
@@ -223,7 +237,9 @@ sub resize_term
    $term->resize( $lines, $cols );
 }
 
-=head2 presskey( $type, $str, $mod )
+=head2 presskey
+
+   presskey( $type, $str, $mod )
 
 Fire a key event
 
@@ -240,7 +256,9 @@ sub presskey
    } );
 }
 
-=head2 pressmouse( $ev, $button, $line, $col, $mod )
+=head2 pressmouse
+
+   pressmouse( $ev, $button, $line, $col, $mod )
 
 Fire a mouse button event
 
@@ -261,7 +279,7 @@ sub pressmouse
 
 =head1 TEST FUNCTIONS
 
-The following functions can be used like C<Test::More> primatives, in unit
+The following functions can be used like C<Test::More> primitives, in unit
 test scripts.
 
 =cut
@@ -281,7 +299,9 @@ sub _pen2string
    return "{" . join( ",", map { defined $attrs{$_} ? "$_=" . ($attrs{$_} || 0) : "!$_" } sort keys %attrs ) . "}";
 }
 
-=head2 is_termlog( [ @log ], $name )
+=head2 is_termlog
+
+   is_termlog( [ @log ], $name )
 
 Asserts that the mock terminal log contains exactly the given sequence of
 methods. See also the helper functions below.
@@ -290,7 +310,7 @@ Because this test is quite fragile, relying on the exact nature and order of
 drawing methods invoked on the terminal, it should only be used rarely. Most
 normal cases of widget unit tests should instead only use C<is_display>.
 
-=head2 is_termlog( { $pos => \@log, ... }, $name )
+   is_termlog( { $pos => \@log, ... }, $name )
 
 The expectation HASH is keyed by strings giving a GOTO position, and the test
 asserts that a sequence of GOTO and other operations were performed equivalent
@@ -412,7 +432,9 @@ sub is_termlog
    return $tb->ok( 1, $name );
 }
 
-=head2 is_display( $lines, $name )
+=head2 is_display
+
+   is_display( $lines, $name )
 
 Asserts that the mock terminal display is exactly that as given by the content
 of C<$lines>, which must be an ARRAY reference containing one value for each
@@ -538,7 +560,9 @@ sub is_display
    return $tb->ok( 1, $name );
 }
 
-=head2 is_cursorpos( $line, $col, $name )
+=head2 is_cursorpos
+
+   is_cursorpos( $line, $col, $name )
 
 Asserts that the mock terminal cursor is at the given position.
 
