@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Window;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use 5.010; # //
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Carp;
 
@@ -117,6 +117,8 @@ sub new
       my ( $term, $ev, $args ) = @_;
       Tickit::Debug->log( Ir => "Resize to $args->{cols}x$args->{lines}" ) if DEBUG;
       $weakself->resize( $args->{lines}, $args->{cols} );
+
+      return 1;
    } );
 
    weaken( $self->{tickit} );
@@ -130,7 +132,6 @@ sub _init
    my $self = shift;
    $self->{visible} = 1;
    $self->{pen}     = Tickit::Pen->new;
-   $self->{expose_after_scroll} = 1;
    $self->{cursor_visible} = 1;
 }
 
@@ -203,7 +204,9 @@ sub _on_later
 
 =cut
 
-=head2 $win->close
+=head2 close
+
+   $win->close
 
 Removes the window from its parent and clears any event handlers set using any
 of the C<set_on_*> methods. Also recursively closes any child windows.
@@ -307,7 +310,9 @@ sub _make_sub
    return $sub;
 }
 
-=head2 $sub = $win->make_sub( $top, $left, $lines, $cols )
+=head2 make_sub
+
+   $sub = $win->make_sub( $top, $left, $lines, $cols )
 
 Constructs a new sub-window of the given geometry, and places it at the end of
 the child window list; below any other siblings.
@@ -327,7 +332,9 @@ sub make_sub
    return $sub;
 }
 
-=head2 $sub = $win->make_hidden_sub( $top, $left, $lines, $cols )
+=head2 make_hidden_sub
+
+   $sub = $win->make_hidden_sub( $top, $left, $lines, $cols )
 
 Constructs a new sub-window like C<make_sub>, but the window starts initially
 hidden. This avoids having to call C<hide> separately afterwards.
@@ -347,7 +354,9 @@ sub make_hidden_sub
    return $sub;
 }
 
-=head2 $float = $win->make_float( $top, $left, $lines, $cols )
+=head2 make_float
+
+   $float = $win->make_float( $top, $left, $lines, $cols )
 
 Constructs a new sub-window of the given geometry, and places it at the start
 of the child window list; above any other siblings.
@@ -367,7 +376,9 @@ sub make_float
    return $sub;
 }
 
-=head2 $popup = $win->make_popup( $top, $left, $lines, $cols )
+=head2 make_popup
+
+   $popup = $win->make_popup( $top, $left, $lines, $cols )
 
 Constructs a new floating popup window starting at the given coordinates
 relative to this window. It will be sized to the given limits.
@@ -396,7 +407,9 @@ sub make_popup
    return $popup;
 }
 
-=head2 $win->raise
+=head2 raise
+
+   $win->raise
 
 =cut
 
@@ -407,7 +420,9 @@ sub raise
    $self->parent->_reorder_child( $self, -1 );
 }
 
-=head2 $win->lower
+=head2 lower
+
+   $win->lower
 
 Moves the order of the window in its parent one higher or lower relative to
 its siblings.
@@ -421,7 +436,9 @@ sub lower
    $self->parent->_reorder_child( $self, +1 );
 }
 
-=head2 $win->raise_to_front
+=head2 raise_to_front
+
+   $win->raise_to_front
 
 Moves the order of the window in its parent to be the front-most among its
 siblings.
@@ -435,7 +452,9 @@ sub raise_to_front
    $self->parent->_reorder_child( $self, "front" );
 }
 
-=head2 $win->lower_to_back
+=head2 lower_to_back
+
+   $win->lower_to_back
 
 Moves the order of the window in its parent to be the back-most among its
 siblings.
@@ -486,7 +505,9 @@ sub _reap_dead_children
    }
 }
 
-=head2 $parentwin = $win->parent
+=head2 parent
+
+   $parentwin = $win->parent
 
 Returns the parent window; i.e. the window on which C<make_sub> or
 C<make_float> was called to create this one
@@ -499,7 +520,9 @@ sub parent
    return $self->{parent};
 }
 
-=head2 @windows = $win->subwindows
+=head2 subwindows
+
+   @windows = $win->subwindows
 
 Returns a list of the subwindows of this one. They are returned in order,
 highest first.
@@ -513,7 +536,9 @@ sub subwindows
    return grep { defined } @$children;
 }
 
-=head2 $rootwin = $win->root
+=head2 root
+
+   $rootwin = $win->root
 
 Returns the root window
 
@@ -528,7 +553,9 @@ sub root
    return $win;
 }
 
-=head2 $term = $win->term
+=head2 term
+
+   $term = $win->term
 
 Returns the L<Tickit::Term> instance of the terminal on which this window
 lives.
@@ -541,7 +568,9 @@ sub term
    return $self->root->{term};
 }
 
-=head2
+=head2 tickit
+
+   $tickit = $win->tickit
 
 Returns the L<Tickit> instance with which this window is associated.
 
@@ -553,7 +582,9 @@ sub tickit
    return $self->root->{tickit};
 }
 
-=head2 $win->show
+=head2 show
+
+   $win->show
 
 Makes the window visible. Allows drawing methods to output to the terminal.
 Calling this method also exposes the window, invoking the C<on_expose>
@@ -576,7 +607,9 @@ sub show
    $self->expose;
 }
 
-=head2 $win->hide
+=head2 hide
+
+   $win->hide
 
 Makes the window invisible. Prevents drawing methods outputting to the
 terminal. Hides the cursor if this window currently has focus.
@@ -596,7 +629,9 @@ sub hide
    }
 }
 
-=head2 $visible = $win->is_visible
+=head2 is_visible
+
+   $visible = $win->is_visible
 
 Returns true if the window is currently visible.
 
@@ -608,7 +643,9 @@ sub is_visible
    return $self->{visible};
 }
 
-=head2 $win->resize( $lines, $cols )
+=head2 resize
+
+   $win->resize( $lines, $cols )
 
 Change the size of the window.
 
@@ -622,7 +659,9 @@ sub resize
    $self->change_geometry( $self->top, $self->left, $lines, $cols );
 }
 
-=head2 $win->reposition( $top, $left )
+=head2 reposition
+
+   $win->reposition( $top, $left )
 
 Move the window relative to its parent.
 
@@ -637,7 +676,9 @@ sub reposition
    $self->_needs_restore if $self->is_focused;
 }
 
-=head2 $win->change_geometry( $top, $left, $lines, $cols )
+=head2 change_geometry
+
+   $win->change_geometry( $top, $left, $lines, $cols )
 
 A combination of C<resize> and C<reposition>, to atomically change all the
 coordinates of the window. Will only invoke C<on_geom_changed> once, rather
@@ -665,7 +706,9 @@ sub change_geometry
    }
 }
 
-=head2 $win->set_on_geom_changed( $on_geom_changed )
+=head2 set_on_geom_changed
+
+   $win->set_on_geom_changed( $on_geom_changed )
 
 Set the callback to invoke whenever the window is resized or repositioned;
 i.e. whenever its geometry changes.
@@ -680,9 +723,11 @@ sub set_on_geom_changed
    ( $self->{on_geom_changed} ) = @_;
 }
 
-=head2 $win->set_on_key( $on_key )
+=head2 set_on_key
 
-=head2 $win->set_on_key( with_ev => $on_key )
+   $win->set_on_key( $on_key )
+
+   $win->set_on_key( with_ev => $on_key )
 
 Set the callback to invoke whenever a key is pressed while this window, or one
 of its child windows, has the input focus. The callback will be passed the
@@ -764,9 +809,11 @@ sub _handle_key
    return 0;
 }
 
-=head2 $win->set_on_mouse( $on_mouse )
+=head2 set_on_mouse
 
-=head2 $win->set_on_mouse( with_ev => $on_mouse )
+   $win->set_on_mouse( $on_mouse )
+
+   $win->set_on_mouse( with_ev => $on_mouse )
 
 Set the callback to invoke whenever a mouse event is received within the
 window's rectangle. The callback will be passed the window and an event
@@ -887,9 +934,11 @@ sub _handle_mouse
    return 0;
 }
 
-=head2 $win->set_on_expose( $on_expose )
+=head2 set_on_expose
 
-=head2 $win->set_on_expose( with_rb => $on_expose )
+   $win->set_on_expose( $on_expose )
+
+   $win->set_on_expose( with_rb => $on_expose )
 
 Set the callback to invoke whenever a region of the window is exposed by the
 C<expose> event. When invoked, it is passed the window itself, a
@@ -956,7 +1005,9 @@ sub _do_expose
    }
 }
 
-=head2 $win->expose( $rect )
+=head2 expose
+
+   $win->expose( $rect )
 
 Marks the given region of the window as having been exposed, to invoke the
 C<on_expose> event handler on itself, and all its child windows. The window's
@@ -1002,7 +1053,9 @@ sub expose
    $self->_needs_later;
 }
 
-=head2 $win->set_on_focus( $on_refocus )
+=head2 set_on_focus
+
+   $win->set_on_focus( $on_refocus )
 
 Set the callback to invoke whenever the window gains or loses focus.
 
@@ -1032,7 +1085,9 @@ sub set_on_focus
    ( $self->{on_focus} ) = @_;
 }
 
-=head2 $win->set_focus_child_notify( $notify )
+=head2 set_focus_child_notify
+
+   $win->set_focus_child_notify( $notify )
 
 If set to a true value, the C<on_focus> event handler will also be invoked
 when descendent windows gain or lose focus, in addition to when it gains or
@@ -1047,35 +1102,35 @@ sub set_focus_child_notify
    ( $self->{focus_child_notify} ) = @_;
 }
 
-=head2 $win->set_expose_after_scroll( $expose_after_scroll )
+=head2 set_expose_after_scroll
 
-If set to a true value, the C<scrollrect> method will expose the region of
-the window that requires redrawing. If C<scrollrect> was successful, this will
-be just the newly-exposed portion that was scrolled in. If it was unsuccessful
-it will be the entire window region. If set false, no expose will happen, and
-the code calling C<scrollrect> must re-expose as required.
+   $win->set_expose_after_scroll( ... )
 
-This behaviour now defaults to true, and this is a temporary method to handle
-the transition of behaviours. This method exists only to allow this behaviour
-to be disabled as a temporary transition measure. It will be removed in a
-later version.
+This method is now deprecated; the setting is always enabled and can no longer
+be disabled. This method throws an exception if invoked.
 
 =cut
 
 sub set_expose_after_scroll
 {
-   my $self = shift;
-   ( $self->{expose_after_scroll} ) = @_;
-   warn "Disabling expose_after_scroll is now deprecated" if !$self->{expose_after_scroll};
+   croak "expose_after_scroll is deprecated";
 }
 
-=head2 $top = $win->top
+=head2 top
 
-=head2 $bottom = $win->bottom
+=head2 bottom
 
-=head2 $left = $win->left
+=head2 left
 
-=head2 $right = $win->right
+=head2 right
+
+   $top    = $win->top
+
+   $bottom = $win->bottom
+
+   $left   = $win->left
+
+   $right  = $win->right
 
 Returns the coordinates of the start of the window, relative to the parent
 window.
@@ -1106,9 +1161,13 @@ sub right
    return $self->left + $self->cols;
 }
 
-=head2 $top  = $win->abs_top
+=head2 abs_top
 
-=head2 $left = $win->abs_left
+=head2 abs_left
+
+   $top  = $win->abs_top
+
+   $left = $win->abs_left
 
 Returns the coordinates of the start of the window, relative to the root
 window.
@@ -1135,9 +1194,13 @@ sub abs_left
    return $left;
 }
 
-=head2 $cols = $win->cols
+=head2 cols
 
-=head2 $lines = $win->lines
+=head2 lines
+
+   $cols  = $win->cols
+
+   $lines = $win->lines
 
 Obtain the size of the window
 
@@ -1155,7 +1218,9 @@ sub lines
    return $self->{lines};
 }
 
-=head2 $rect = $win->selfrect
+=head2 selfrect
+
+   $rect = $win->selfrect
 
 Returns a L<Tickit::Rect> containing representing the window's extent within
 itself. This will have C<top> and C<left> equal to 0.
@@ -1174,7 +1239,9 @@ sub selfrect
    );
 }
 
-=head2 $rect = $win->rect
+=head2 rect
+
+   $rect = $win->rect
 
 Returns a L<Tickit::Rect> containing representing the window's extent relative
 to its parent
@@ -1193,7 +1260,9 @@ sub rect
    );
 }
 
-=head2 $pen = $win->pen
+=head2 pen
+
+   $pen = $win->pen
 
 Returns the current L<Tickit::Pen> object associated with this window
 
@@ -1205,7 +1274,9 @@ sub pen
    return $self->{pen};
 }
 
-=head2 $win->set_pen( $pen )
+=head2 set_pen
+
+   $win->set_pen( $pen )
 
 Replace the current L<Tickit::Pen> object for this window with a new one. The
 object reference will be stored, allowing it to be shared with other objects.
@@ -1220,7 +1291,9 @@ sub set_pen
    defined $self->{pen} or $self->{pen} = Tickit::Pen->new;
 }
 
-=head2 $val = $win->getpenattr( $attr )
+=head2 getpenattr
+
+   $val = $win->getpenattr( $attr )
 
 Returns a single attribue from the current pen
 
@@ -1234,7 +1307,9 @@ sub getpenattr
    return $self->{pen}->getattr( $attr );
 }
 
-=head2 $pen = $win->get_effective_pen
+=head2 get_effective_pen
+
+   $pen = $win->get_effective_pen
 
 Returns a new L<Tickit::Pen> containing the effective pen attributes for the
 window, combined by those of all its parents.
@@ -1253,7 +1328,9 @@ sub get_effective_pen
    return $pen;
 }
 
-=head2 $val = $win->get_effective_penattr( $attr )
+=head2 get_effective_penattr
+
+   $val = $win->get_effective_penattr( $attr )
 
 Returns the effective value of a pen attribute. This will be the value of this
 window's attribute if set, or the effective value of the attribute from its
@@ -1333,13 +1410,15 @@ sub _get_span_visibility
    return ( $vis, $len );
 }
 
-=head2 $success = $win->scrollrect( $rect, $downward, $rightward )
+=head2 scrollrect
 
-=head2 $success = $win->scrollrect( $top, $left, $lines, $cols, $downward, $rightward )
+   $success = $win->scrollrect( $rect, $downward, $rightward )
 
-=head2 $success = $win->scrollrect( ..., $pen )
+   $success = $win->scrollrect( $top, $left, $lines, $cols, $downward, $rightward )
 
-=head2 $success = $win->scrollrect( ..., %attrs )
+   $success = $win->scrollrect( ..., $pen )
+
+   $success = $win->scrollrect( ..., %attrs )
 
 Attempt to scroll the rectangle of the window (either given by a
 C<Tickit::Rect> or defined by the first four parameters) by an amount given
@@ -1357,9 +1436,8 @@ undefined if this method returns successful. The terminal pen, in particular
 the background colour, may be modified by this method even if it fails to
 scroll the terminal (and returns false).
 
-If the C<expose_after_scroll> behavior is enabled, then this method will
-enqueue all of the required expose requests before returning, so in this case
-the return value is not interesting.
+This method will enqueue all of the required expose requests before returning,
+so in this case the return value is not interesting.
 
 =cut
 
@@ -1369,7 +1447,6 @@ sub _scrollrectset
    my ( $rectset, $downward, $rightward, $pen ) = @_;
 
    my $origwin = $win;
-   my $expose_after_scroll = $win->{expose_after_scroll};
 
    while( $win ) {
       return 0 unless $win->is_visible;
@@ -1407,7 +1484,7 @@ sub _scrollrectset
       my $origrect = $rect->translate( -$origwin->abs_top, -$origwin->abs_left );
 
       if( abs($downward) >= $lines or abs($rightward) >= $cols ) {
-         $origwin->expose( $origrect ) if $expose_after_scroll;
+         $origwin->expose( $origrect );
          next;
       }
 
@@ -1439,44 +1516,37 @@ sub _scrollrectset
 
       if( not $term->scrollrect( $top, $left, $lines, $cols, $downward, $rightward ) ) {
          $ret = 0;
-         if( $expose_after_scroll ) {
-            $origwin->expose( $origrect );
-         }
+         $origwin->expose( $origrect );
       }
 
-      if( $expose_after_scroll ) {
-         if( $downward > 0 ) {
-            # "scroll down" means lines moved upward, so the bottom needs redrawing
-            $origwin->expose( Tickit::Rect->new(
-                  top  => $origrect->bottom - $downward, lines => $downward,
-                  left => $origrect->left,               cols  => $cols,
-            ) );
-         }
-         elsif( $downward < 0 ) {
-            # "scroll up" means lines moved downward, so top needs redrawing
-            $origwin->expose( Tickit::Rect->new(
-                  top  => $origrect->top,  lines => -$downward,
-                  left => $origrect->left, cols  => $cols,
-            ) );
-         }
-
-         if( $rightward > 0 ) {
-            # "scroll right" means columns moved leftward, so the right edge needs redrawing
-            $origwin->expose( Tickit::Rect->new(
-                  top  => $origrect->top,                lines => $lines,
-                  left => $origrect->right - $rightward, cols  => $rightward,
-            ) );
-         }
-         elsif( $rightward < 0 ) {
-            # "scroll left" means lines moved rightward, so left edge needs redrawing
-            $origwin->expose( Tickit::Rect->new(
-                  top  => $origrect->top,  lines => $lines,
-                  left => $origrect->left, cols  => -$rightward,
-            ) );
-         }
+      if( $downward > 0 ) {
+         # "scroll down" means lines moved upward, so the bottom needs redrawing
+         $origwin->expose( Tickit::Rect->new(
+               top  => $origrect->bottom - $downward, lines => $downward,
+               left => $origrect->left,               cols  => $cols,
+         ) );
       }
-      else {
-         $origwin->_needs_flush;
+      elsif( $downward < 0 ) {
+         # "scroll up" means lines moved downward, so top needs redrawing
+         $origwin->expose( Tickit::Rect->new(
+               top  => $origrect->top,  lines => -$downward,
+               left => $origrect->left, cols  => $cols,
+         ) );
+      }
+
+      if( $rightward > 0 ) {
+         # "scroll right" means columns moved leftward, so the right edge needs redrawing
+         $origwin->expose( Tickit::Rect->new(
+               top  => $origrect->top,                lines => $lines,
+               left => $origrect->right - $rightward, cols  => $rightward,
+         ) );
+      }
+      elsif( $rightward < 0 ) {
+         # "scroll left" means lines moved rightward, so left edge needs redrawing
+         $origwin->expose( Tickit::Rect->new(
+               top  => $origrect->top,  lines => $lines,
+               left => $origrect->left, cols  => -$rightward,
+         ) );
       }
    }
 
@@ -1520,7 +1590,9 @@ sub scrollrect
    $self->_scrollrectset( $visible, $downward, $rightward, $pen );
 }
 
-=head2 $success = $win->scroll( $downward, $rightward )
+=head2 scroll
+
+   $success = $win->scroll( $downward, $rightward )
 
 A shortcut for calling C<scrollrect> on the entire region of the window.
 
@@ -1537,7 +1609,9 @@ sub scroll
    );
 }
 
-=head2 $win->scroll_with_children( $downward, $rightward )
+=head2 scroll_with_children
+
+   $win->scroll_with_children( $downward, $rightward )
 
 Similar to C<scroll> but ignores child windows of this one, moving all of
 the terminal content paying attention only to obscuring by newer siblings of
@@ -1563,7 +1637,9 @@ sub scroll_with_children
    $self->_scrollrectset( $visible, $downward, $rightward, $pen );
 }
 
-=head2 $win->cursor_at( $line, $col )
+=head2 cursor_at
+
+   $win->cursor_at( $line, $col )
 
 Sets the position in the window at which the terminal cursor will be placed if
 this window has focus. This method does I<not> force the window to take the
@@ -1578,7 +1654,9 @@ sub cursor_at
    $self->_needs_restore if $self->is_focused;
 }
 
-=head2 $win->cursor_visible( $visible )
+=head2 cursor_visible
+
+   $win->cursor_visible( $visible )
 
 Sets whether the terminal cursor is visible on the window when it has focus.
 Normally it is, but passing a false value will make the cursor hidden even
@@ -1593,7 +1671,9 @@ sub cursor_visible
    $self->_needs_restore if $self->is_focused;
 }
 
-=head2 $win->cursor_shape( $shape )
+=head2 cursor_shape
+
+   $win->cursor_shape( $shape )
 
 Sets the shape that the terminal cursor will have if this window has focus.
 This method does I<not> force the window to take the focus though; for that
@@ -1609,7 +1689,9 @@ sub cursor_shape
    $self->_needs_restore if $self->is_focused;
 }
 
-=head2 $win->take_focus
+=head2 take_focus
+
+   $win->take_focus
 
 Causes this window to take the input focus, and updates the cursor position to
 the stored active position given by C<cursor_at>.
@@ -1624,7 +1706,9 @@ sub take_focus
    $self->_focus_gained
 }
 
-=head2 $win->focus( $line, $col )
+=head2 focus
+
+   $win->focus( $line, $col )
 
 A convenient shortcut combining C<cursor_at> with C<take_focus>; setting the
 focus cursor position and taking the input focus.
@@ -1682,7 +1766,9 @@ sub _focus_lost
    }
 }
 
-=head2 $focused = $win->is_focused
+=head2 is_focused
+
+   $focused = $win->is_focused
 
 Returns true if this window currently has the input focus
 
@@ -1694,7 +1780,9 @@ sub is_focused
    return defined $self->{focused};
 }
 
-=head2 $win->restore
+=head2 restore
+
+   $win->restore
 
 Restore the state of the terminal to its idle state. Places the cursor back
 at the focus position, and restores the pen.
@@ -1729,7 +1817,9 @@ sub restore
    $term->flush;
 }
 
-=head2 $win->clearline( $line )
+=head2 clearline
+
+   $win->clearline( $line )
 
 Erase the entire content of one line of the window
 
@@ -1746,7 +1836,9 @@ sub clearline
    $self->erasech( $self->cols );
 }
 
-=head2 $win->clear
+=head2 clear
+
+   $win->clear
 
 Erase the entire content of the window and reset it to the current background
 colour.
