@@ -6,6 +6,8 @@
 #define ROOT_AS_WINDOW(root) ((TickitWindow*)root)
 #define WINDOW_AS_ROOT(win)  ((TickitRootWindow*)win)
 
+#define DEBUG_LOGF  if(tickit_debug_enabled) tickit_debug_logf
+
 typedef enum {
   TICKIT_HIERARCHY_INSERT_FIRST,
   TICKIT_HIERARCHY_INSERT_LAST,
@@ -37,6 +39,12 @@ struct TickitWindow {
   struct TickitEventHook *hooks;
 };
 
+#define WINDOW_PRINTF_FMT     "[%dx%d abs@%d,%d]"
+#define WINDOW_PRINTF_ARGS(w) (w)->rect.cols, (w)->rect.lines, tickit_window_get_abs_geometry(w).left, tickit_window_get_abs_geometry(w).top
+
+#define RECT_PRINTF_FMT     "[(%d,%d)..(%d,%d)]"
+#define RECT_PRINTF_ARGS(r) (r).left, (r).top, tickit_rect_right(&(r)), tickit_rect_bottom(&(r))
+
 DEFINE_HOOKLIST_FUNCS(window,TickitWindow,TickitWindowEventFn)
 
 typedef struct HierarchyChange HierarchyChange;
@@ -59,6 +67,13 @@ struct TickitRootWindow {
   bool needs_later_processing;
 
   int event_id;
+
+  // Drag/drop context handling
+  bool mouse_dragging;
+  int mouse_last_button;
+  int mouse_last_line;
+  int mouse_last_col;
+  TickitWindow *drag_source_window;
 };
 
 static void _request_restore(TickitRootWindow *root);
@@ -67,7 +82,7 @@ static void _request_hierarchy_change(HierarchyChangeType, TickitWindow *);
 static void _do_hierarchy_change(HierarchyChangeType change, TickitWindow *parent, TickitWindow *win);
 static void _purge_hierarchy_changes(TickitWindow *win);
 static int _handle_key(TickitWindow *win, TickitKeyEventInfo *args);
-static int _handle_mouse(TickitWindow *win, TickitMouseEventInfo *args);
+static TickitWindow *_handle_mouse(TickitWindow *win, TickitMouseEventInfo *args);
 
 static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user)
 {
@@ -80,6 +95,8 @@ static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user
     int oldcols  = win->rect.cols;
 
     tickit_window_resize(win, info->lines, info->cols);
+    DEBUG_LOGF("Ir", "Resize to %dx%d",
+        info->cols, info->lines);
 
     if(info->lines > oldlines) {
       TickitRect damage = {
@@ -102,11 +119,81 @@ static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user
     }
   }
 
-  if(ev & TICKIT_EV_KEY)
-    _handle_key(win, (TickitKeyEventInfo *)_info);
+  if(ev & TICKIT_EV_KEY) {
+    TickitKeyEventInfo *info = _info;
+    static const char * const evnames[] = { NULL, "KEY", "TEXT" };
 
-  if(ev & TICKIT_EV_MOUSE)
-    _handle_mouse(win, (TickitMouseEventInfo *)_info);
+    DEBUG_LOGF("Ik", "Key event %s %s (mod=%02x)",
+        evnames[info->type], info->str, info->mod);
+
+    _handle_key(win, info);
+  }
+
+  if(ev & TICKIT_EV_MOUSE) {
+    TickitMouseEventInfo *info = _info;
+    static const char * const evnames[] = { NULL, "PRESS", "DRAG", "RELEASE", "WHEEL" };
+
+    DEBUG_LOGF("Im", "Mouse event %s %d @%d,%d (mod=%02x)",
+        evnames[info->type], info->button, info->col, info->line, info->mod);
+
+    if(info->type == TICKIT_MOUSEEV_PRESS) {
+      /* Save the last press location in case of drag */
+      root->mouse_last_button = info->button;
+      root->mouse_last_line   = info->line;
+      root->mouse_last_col    = info->col;
+    }
+    else if(info->type == TICKIT_MOUSEEV_DRAG && !root->mouse_dragging) {
+      TickitMouseEventInfo draginfo = {
+        .type   = TICKIT_MOUSEEV_DRAG_START,
+        .button = root->mouse_last_button,
+        .line   = root->mouse_last_line,
+        .col    = root->mouse_last_col,
+      };
+
+      root->drag_source_window = _handle_mouse(win, &draginfo);
+      root->mouse_dragging = true;
+    }
+    else if(info->type == TICKIT_MOUSEEV_RELEASE && root->mouse_dragging) {
+      TickitMouseEventInfo draginfo = {
+        .type   = TICKIT_MOUSEEV_DRAG_DROP,
+        .button = info->button,
+        .line   = info->line,
+        .col    = info->col,
+      };
+
+      _handle_mouse(win, &draginfo);
+
+      if(root->drag_source_window) {
+        TickitRect geom = tickit_window_get_abs_geometry(root->drag_source_window);
+        TickitMouseEventInfo draginfo = {
+          .type   = TICKIT_MOUSEEV_DRAG_STOP,
+          .button = info->button,
+          .line   = info->line - geom.top,
+          .col    = info->col  - geom.left,
+        };
+
+        _handle_mouse(root->drag_source_window, &draginfo);
+      }
+
+      root->mouse_dragging = false;
+    }
+
+    TickitWindow *handled = _handle_mouse(win, info);
+
+    if(info->type == TICKIT_MOUSEEV_DRAG &&
+       root->drag_source_window &&
+       (!handled || handled != root->drag_source_window)) {
+      TickitRect geom = tickit_window_get_abs_geometry(root->drag_source_window);
+      TickitMouseEventInfo draginfo = {
+        .type   = TICKIT_MOUSEEV_DRAG_OUTSIDE,
+        .button = info->button,
+        .line   = info->line - geom.top,
+        .col    = info->col  - geom.left,
+      };
+
+      _handle_mouse(root->drag_source_window, &draginfo);
+    }
+  }
 
   return 1;
 }
@@ -155,7 +242,9 @@ TickitWindow* tickit_window_new_root(TickitTerm *term)
   }
 
   root->event_id = tickit_term_bind_event(term, TICKIT_EV_RESIZE|TICKIT_EV_KEY|TICKIT_EV_MOUSE,
-      &on_term, root);
+      0, &on_term, root);
+
+  root->mouse_dragging = false;
 
   tickit_window_expose(ROOT_AS_WINDOW(root), NULL);
 
@@ -390,6 +479,9 @@ void tickit_window_expose(TickitWindow *win, const TickitRect *exposed)
     return;
   }
 
+  DEBUG_LOGF("Wd", "Damage root " RECT_PRINTF_FMT,
+      RECT_PRINTF_ARGS(damaged));
+
   /* If we're here, then we're a root win. */
   TickitRootWindow *root = WINDOW_AS_ROOT(win);
   if(tickit_rectset_contains(root->damage, &damaged))
@@ -401,8 +493,34 @@ void tickit_window_expose(TickitWindow *win, const TickitRect *exposed)
   _request_later_processing(root);
 }
 
+static char *_gen_indent(TickitWindow *win)
+{
+  int depth = 0;
+  while(win->parent) {
+    depth++;
+    win = win->parent;
+  }
+
+  static size_t buflen = 0;
+  static char *buf = NULL;
+
+  if(depth * 2 >= buflen) {
+    free(buf);
+    buf = malloc(buflen = (depth * 2 + 1));
+    buf[0] = 0;
+  }
+
+  for(char *s = buf; depth; depth--, s += 2)
+    s[0] = '|', s[1] = ' ';
+
+  return buf;
+}
+
 static void _do_expose(TickitWindow *win, const TickitRect *rect, TickitRenderBuffer *rb)
 {
+  DEBUG_LOGF("Wx", "%sExpose " WINDOW_PRINTF_FMT " " RECT_PRINTF_FMT,
+      _gen_indent(win), WINDOW_PRINTF_ARGS(win), RECT_PRINTF_ARGS(*rect));
+
   if(win->pen)
     tickit_renderbuffer_setpen(rb, win->pen);
 
@@ -632,34 +750,47 @@ static void _do_hierarchy_lower(TickitWindow *parent, TickitWindow *win)
 
 static void _do_hierarchy_change(HierarchyChangeType change, TickitWindow *parent, TickitWindow *win)
 {
+  const char *fmt = NULL;
+
   switch(change) {
     case TICKIT_HIERARCHY_INSERT_FIRST:
+       fmt = "Window " WINDOW_PRINTF_FMT " adds " WINDOW_PRINTF_FMT;
       _do_hierarchy_insert_first(parent, win);
       break;
     case TICKIT_HIERARCHY_INSERT_LAST:
+      fmt = "Window " WINDOW_PRINTF_FMT " adds " WINDOW_PRINTF_FMT;
       _do_hierarchy_insert_last(parent, win);
       break;
     case TICKIT_HIERARCHY_REMOVE:
+      fmt = "Window " WINDOW_PRINTF_FMT " removes " WINDOW_PRINTF_FMT;
       _do_hierarchy_remove(parent, win);
       if(parent->focused_child && parent->focused_child == win)
         parent->focused_child = NULL;
       break;
     case TICKIT_HIERARCHY_RAISE:
+      fmt = "Window " WINDOW_PRINTF_FMT " raises " WINDOW_PRINTF_FMT;
       _do_hierarchy_raise(parent, win);
       break;
     case TICKIT_HIERARCHY_RAISE_FRONT:
+      fmt = "Window " WINDOW_PRINTF_FMT " raises " WINDOW_PRINTF_FMT " to front";
       _do_hierarchy_remove(parent, win);
       _do_hierarchy_insert_first(parent, win);
       break;
     case TICKIT_HIERARCHY_LOWER:
+      fmt = "Window " WINDOW_PRINTF_FMT " lowers " WINDOW_PRINTF_FMT;
       _do_hierarchy_lower(parent, win);
       break;
     case TICKIT_HIERARCHY_LOWER_BACK:
+      fmt = "Window " WINDOW_PRINTF_FMT " lowers " WINDOW_PRINTF_FMT " to back";
       _do_hierarchy_remove(parent, win);
       _do_hierarchy_insert_last(parent, win);
       break;
   }
 
+  if(fmt)
+    DEBUG_LOGF("Wh", fmt,
+        WINDOW_PRINTF_ARGS(parent), WINDOW_PRINTF_ARGS(win));
+
   tickit_window_expose(parent, &win->rect);
 }
 
@@ -787,6 +918,9 @@ static bool _scrollrectset(TickitWindow *win, TickitRectSet *visible, int downwa
       }
     }
 
+    DEBUG_LOGF("Wsr", "Term scrollrect " RECT_PRINTF_FMT " by %+d,%+d",
+      RECT_PRINTF_ARGS(rect), rightward, downward);
+
     if(!done_pen) {
       // TODO: only bg matters
       tickit_term_setpen(term, pen);
@@ -840,6 +974,9 @@ static bool _scroll(TickitWindow *win, const TickitRect *origrect, int downward,
   if(!tickit_rect_intersect(&rect, &selfrect, origrect))
     return false;
 
+  DEBUG_LOGF("Ws", "Scroll " RECT_PRINTF_FMT " by %+d,%+d",
+    RECT_PRINTF_ARGS(rect), rightward, downward);
+
   if(pen)
     pen = tickit_pen_ref(pen);
   else
@@ -998,10 +1135,10 @@ static int _handle_key(TickitWindow *win, TickitKeyEventInfo *info)
   return 0;
 }
 
-static int _handle_mouse(TickitWindow *win, TickitMouseEventInfo *info)
+static TickitWindow *_handle_mouse(TickitWindow *win, TickitMouseEventInfo *info)
 {
   if(!win->is_visible)
-    return 0;
+    return NULL;
 
   for(TickitWindow *child = win->first_child; child; child = child->next) {
     int child_line = info->line - child->rect.top;
@@ -1018,12 +1155,13 @@ static int _handle_mouse(TickitWindow *win, TickitMouseEventInfo *info)
     childinfo.line = child_line;
     childinfo.col  = child_col;
 
-    if(_handle_mouse(child, &childinfo))
-      return 1;
+    TickitWindow *ret;
+    if((ret = _handle_mouse(child, &childinfo)))
+      return ret;
   }
 
   if(run_events_whilefalse(win, TICKIT_EV_MOUSE, info))
-    return 1;
+    return win;
 
   return 0;
 }
